Stan Math Library: stan/math/prim/scal/fun/constants.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions | Variables
constants.hpp File Reference
`#include <boost/math/constants/constants.hpp>`
`#include <limits>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
double | stan::math::pi ()
| Return the value of pi. More...
double | stan::math::e ()
| Return the base of the natural logarithm. More...
double | stan::math::sqrt2 ()
| Return the square root of two. More...
double | stan::math::log10 ()
| Return natural logarithm of ten. More...
double | stan::math::positive_infinity ()
| Return positive infinity. More...
double | stan::math::negative_infinity ()
| Return negative infinity. More...
double | stan::math::not_a_number ()
| Return (quiet) not-a-number. More...
double | stan::math::machine_precision ()
| Returns the difference between 1.0 and the next value representable. More...

## Variables
const double | stan::math::E = boost::math::constants::e<double>()
| The base of the natural logarithm, . More...
const double | stan::math::SQRT_2 = std::sqrt(2.0)
| The value of the square root of 2, . More...
const double | stan::math::INV_SQRT_2 = 1.0 / SQRT_2
| The value of 1 over the square root of 2, . More...
const double | stan::math::LOG_2 = std::log(2.0)
| The natural logarithm of 2, . More...
const double | stan::math::LOG_10 = std::log(10.0)
| The natural logarithm of 10, . More...
const double | stan::math::INFTY = std::numeric_limits<double>::infinity()
| Positive infinity. More...
const double | stan::math::NEGATIVE_INFTY = - std::numeric_limits<double>::infinity()
| Negative infinity. More...
const double | stan::math::NOT_A_NUMBER = std::numeric_limits<double>::quiet_NaN()
| (Quiet) not-a-number value. More...
const double | stan::math::EPSILON = std::numeric_limits<double>::epsilon()
| Smallest positive value. More...
const double | stan::math::NEGATIVE_EPSILON = - std::numeric_limits<double>::epsilon()
| Largest negative value (i.e., smallest absolute value). More...
const double | stan::math::POISSON_MAX_RATE = std::pow(2.0, 30)
| Largest rate parameter allowed in Poisson RNG. More...
const double | stan::math::LOG_PI_OVER_FOUR = std::log(boost::math::constants::pi<double>()) / 4.0
| Log pi divided by 4 . More...
const double | stan::math::SQRT_PI = std::sqrt(boost::math::constants::pi<double>())
const double | stan::math::SQRT_2_TIMES_SQRT_PI = SQRT_2 * SQRT_PI
const double | stan::math::TWO_OVER_SQRT_PI = 2.0 / SQRT_PI
const double | stan::math::NEG_TWO_OVER_SQRT_PI = -TWO_OVER_SQRT_PI
const double | stan::math::INV_SQRT_TWO_PI = 1.0 / std::sqrt(2.0 * boost::math::constants::pi<double>())
const double | stan::math::LOG_PI = std::log(boost::math::constants::pi<double>())
const double | stan::math::LOG_SQRT_PI = std::log(SQRT_PI)
const double | stan::math::LOG_ZERO = std::log(0.0)
const double | stan::math::LOG_TWO = std::log(2.0)
const double | stan::math::LOG_HALF = std::log(0.5)
const double | stan::math::NEG_LOG_TWO = - LOG_TWO
const double | stan::math::NEG_LOG_SQRT_TWO_PI = - std::log(std::sqrt(2.0 * boost::math::constants::pi<double>()))
const double | stan::math::NEG_LOG_PI = - LOG_PI
const double | stan::math::NEG_LOG_SQRT_PI = -std::log(std::sqrt(boost::math::constants::pi<double>()))
const double | stan::math::NEG_LOG_TWO_OVER_TWO = - LOG_TWO / 2.0
const double | stan::math::LOG_TWO_PI = LOG_TWO + LOG_PI
const double | stan::math::NEG_LOG_TWO_PI = - LOG_TWO_PI

[ Stan Home Page ] © 2011–2016, Stan Development Team.